@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = "1.05";
+our $VERSION = "1.06";
 
 use Cwd;
 use Term::ReadLine;
@@ -242,26 +242,24 @@ sub run {
             $App_PerlShell_Shell->{shellCmdComplete}->{brace} -= scalar(@c);
         }
 
-        if ((   ( $App_PerlShell_Shell->{shellCmdLine} =~ /,\s*$/ )
-                or ( $App_PerlShell_Shell->{shellCmdComplete}->{parenthesis}
-                    != 0 )
-                or
-                ( $App_PerlShell_Shell->{shellCmdComplete}->{bracket} != 0 )
-                or ( $App_PerlShell_Shell->{shellCmdComplete}->{brace} != 0 )
+        if (( ( $App_PerlShell_Shell->{shellCmdLine} =~ /,\s*$/ )
+              or ( $App_PerlShell_Shell->{shellCmdComplete}->{parenthesis} != 0 )
+              or ( $App_PerlShell_Shell->{shellCmdComplete}->{bracket} != 0 )
+              or ( $App_PerlShell_Shell->{shellCmdComplete}->{brace} != 0 )
             )
             or
 
             # valid endings are ; or }, but only if all groupings are closed
-            (   ( $App_PerlShell_Shell->{shellCmdLine} !~ /(;|\})\s*$/ )
-                and ( $App_PerlShell_Shell->{shellCmdComplete}->{parenthesis}
-                    == 0 )
-                and
-                ( $App_PerlShell_Shell->{shellCmdComplete}->{bracket} == 0 )
-                and ( $App_PerlShell_Shell->{shellCmdComplete}->{brace} == 0 )
+            ( ( $App_PerlShell_Shell->{shellCmdLine} !~ /(;|\})\s*$/ )
+              and ( $App_PerlShell_Shell->{shellCmdComplete}->{parenthesis} == 0 )
+              and ( $App_PerlShell_Shell->{shellCmdComplete}->{bracket} == 0 )
+              and ( $App_PerlShell_Shell->{shellCmdComplete}->{brace} == 0 )
             )
           ) {
-            $App_PerlShell_Shell->{shellCmdLine} .= "\n";
-            next;
+            if ( $App_PerlShell_Shell->{shellCmdLine} !~ /\n;$/ ) {
+                $App_PerlShell_Shell->{shellCmdLine} .= "\n";
+                next;
+            }
         }
 
         # import subs if not default package
